API Reference
=============

.. currentmodule:: intake_elasticsearch

.. autosummary::
   intake_elasticsearch.elasticsearch_table.ElasticSearchTableSource
   intake_elasticsearch.elasticsearch_seq.ElasticSearchSeqSource

.. autoclass:: intake_elasticsearch.elasticsearch_table.ElasticSearchTableSource
   :members:

.. autoclass:: intake_elasticsearch.elasticsearch_seq.ElasticSearchSeqSource
   :members:
